Property

Enum Property 

pub enum Property<T> {
    Static(T),
    RandomRange(PropRange<T>),
    RandomChoice(Vec<T>),
    Random,
}
Generic property that can be static, randomized within a range, randomly selected from a predetermined list, or entirely random on each read.

Implementation of Default provides Static(T::default())

Variants



Static(T)

Produces the same value



RandomRange(PropRange<T>)

Produces a random value within the given range



RandomChoice(Vec<T>)

Produces a randomly selected value from the given list



Random

Produces a completely random value